@@ -46,6 +46,8 @@
 #include <QtWidgets/QAction>
 #include <QtWidgets/QApplication>
 
+#include <algorithm>
+
 QT_BEGIN_NAMESPACE
 
 static const char *buddyPropertyC = "buddy";
@@ -143,32 +145,23 @@ void BuddyEditor::updateBackground()
     m_updating = true;
     QList<Connection *> newList;
     const LabelList label_list = background()->findChildren<QLabel*>();
-    foreach (QLabel *label, label_list) {
+    for (QLabel *label : label_list) {
         const QString buddy_name = buddy(label, m_formWindow->core());
         if (buddy_name.isEmpty())
             continue;
 
-        const QList<QWidget *> targets = background()->findChildren<QWidget*>(buddy_name);
+        const QWidgetList targets = background()->findChildren<QWidget*>(buddy_name);
         if (targets.isEmpty())
             continue;
 
-        QWidget *target = 0;
-
-        QListIterator<QWidget *> it(targets);
-        while (it.hasNext()) {
-            QWidget *widget = it.next();
-            if (widget && !widget->isHidden()) {
-                target = widget;
-                break;
-            }
-        }
-
-        if (target == 0)
+        const auto wit = std::find_if(targets.cbegin(), targets.cend(),
+                                      [] (const QWidget *w) { return !w->isHidden(); });
+        if (wit == targets.cend())
             continue;
 
         Connection *con = new Connection(this);
         con->setEndPoint(EndPoint::Source, label, widgetRect(label).center());
-        con->setEndPoint(EndPoint::Target, target, widgetRect(target).center());
+        con->setEndPoint(EndPoint::Target, *wit, widgetRect(*wit).center());
         newList.append(con);
     }
 
@@ -179,29 +172,21 @@ void BuddyEditor::updateBackground()
         Connection *con = connection(i);
         QObject *source = con->object(EndPoint::Source);
         QObject *target = con->object(EndPoint::Target);
-        bool found = false;
-        QListIterator<Connection *> it(newList);
-        while (it.hasNext()) {
-            Connection *newConn = it.next();
-            if (newConn->object(EndPoint::Source) == source && newConn->object(EndPoint::Target) == target) {
-                found = true;
-                break;
-            }
-        }
+        const bool found =
+            std::any_of(newList.cbegin(), newList.cend(),
+                        [source, target] (const Connection *nc)
+                        { return nc->object(EndPoint::Source) == source && nc->object(EndPoint::Target) == target; });
         if (found == false)
             toRemove.append(con);
     }
     if (!toRemove.isEmpty()) {
         DeleteConnectionsCommand command(this, toRemove);
         command.redo();
-        foreach (Connection *con, toRemove)
+        for (Connection *con : qAsConst(toRemove))
             delete takeConnection(con);
     }
 
-    QListIterator<Connection *> it(newList);
-    while (it.hasNext()) {
-        Connection *newConn = it.next();
-
+    for (Connection *newConn : qAsConst(newList)) {
         bool found = false;
         const int c = connectionCount();
         for (int i = 0; i < c; i++) {
@@ -228,7 +213,7 @@ void BuddyEditor::setBackground(QWidget *background)
     ConnectionEdit::setBackground(background);
 
     const LabelList label_list = background->findChildren<QLabel*>();
-    foreach (QLabel *label, label_list) {
+    for (QLabel *label : label_list) {
         const QString buddy_name = buddy(label, m_formWindow->core());
         if (buddy_name.isEmpty())
             continue;
@@ -290,9 +275,9 @@ void BuddyEditor::widgetRemoved(QWidget *widget)
     child_list.prepend(widget);
 
     ConnectionSet remove_set;
-    foreach (QWidget *w, child_list) {
+    for (QWidget *w : qAsConst(child_list)) {
         const ConnectionList &cl = connectionList();
-        foreach (Connection *con, cl) {
+        for (Connection *con : cl) {
             if (con->widget(EndPoint::Source) == w || con->widget(EndPoint::Target) == w)
                 remove_set.insert(con, con);
         }
@@ -300,7 +285,7 @@ void BuddyEditor::widgetRemoved(QWidget *widget)
 
     if (!remove_set.isEmpty()) {
         undoStack()->beginMacro(tr("Remove buddies"));
-        foreach (Connection *con, remove_set) {
+        for (Connection *con : qAsConst(remove_set)) {
             setSelected(con, false);
             con->update();
             QWidget *source = con->widget(EndPoint::Source);
@@ -324,7 +309,7 @@ void BuddyEditor::deleteSelected()
         return;
 
     undoStack()->beginMacro(tr("Remove %n buddies", 0, selectedConnections.size()));
-    foreach (Connection *con, selectedConnections) {
+    for (Connection *con : selectedConnections) {
         setSelected(con, false);
         con->update();
         QWidget *source = con->widget(EndPoint::Source);
@@ -349,7 +334,7 @@ void BuddyEditor::autoBuddy()
     // Find already used buddies
     QWidgetList usedBuddies;
     const ConnectionList &beforeConnections = connectionList();
-    foreach (const Connection *c, beforeConnections)
+    for (const Connection *c : beforeConnections)
         usedBuddies.push_back(c->widget(EndPoint::Target));
     // Find potential new buddies, keep lists in sync
     QWidgetList buddies;
@@ -380,7 +365,7 @@ void BuddyEditor::autoBuddy()
     undoStack()->endMacro();
     // Now select all new ones
     const ConnectionList &connections = connectionList();
-    foreach (Connection *con, connections)
+    for (Connection *con : connections)
         setSelected(con, buddies.contains(con->widget(EndPoint::Target)));
 }
 
